# Embutils 
[![PyPI version](https://badge.fury.io/py/embutils.svg)](https://badge.fury.io/py/embutils)
[![Docs Status](https://readthedocs.org/projects/embutils/badge/?version=latest)](https://embutils.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/:license-mit-blue.svg?style=flat-square)](https://badges.mit-license.org)

Python utilities for embedded projects. 

## Installation 
You can get the packaged version from [PyPI](https://pypi.org/project/embutils/):
```
pip install embutils
```